==> graas-observability-utility-1.4.1.tar.gz: graas-observability-utility-1.4.1/graas_utilities/configs.py <==
mappingObject = {
    "shopee_trafficOverview": "graas_mkp_traffic_overview_hourly",
    "shopee_trafficOverviewMonthly": "graas_mkp_traffic_overview_daily",
    "shopee_storeKeyMetrics": "graas_mkp_shop_stats_daily",
    "shopee_storeKeyMetricsMonthly": "graas_mkp_shop_stats_daily",
    "shopee_productOverview": "graas_mkp_product_overview_hourly",
    "shopee_productOverviewMonthly": "graas_mkp_product_overview_daily",
    "shopee_onsiteCampaign": "graas_mkp_onsite_campaigns",
    "shopee_onsiteKeyword": "graas_mkp_onsite_keywords",
    "shopee_productPerformance": "graas_mkp_product_performance",
    "shopee_marketingAddOnDeal": "graas_mkp_deals_overview_daily",
    "shopee_marketingAddOnDealMonthly": "graas_mkp_deals_trends_daily",
    "shopee_marketingShippingFeePromotion": "graas_mkp_voucher_performance_daily",
    "shopee_marketingShippingFeePromotionMonthly": "graas_mkp_deals_trends_daily",
    "shopee_marketingVoucher": "graas_mkp_voucher_performance_daily",
    "shopee_marketingVoucherMonthly": "graas_mkp_deals_trends_daily",
    "shopee_marketingBundleDeal": "graas_mkp_deals_overview_daily",
    "shopee_marketingBundleDealMonthly": "graas_mkp_deals_trends_daily",
    "shopee_marketingFlashDeal": "graas_mkp_deals_overview_daily",
    "shopee_marketingFlashDealMonthly": "graas_mkp_deals_trends_daily",
    "shopee_productPerformanceAfterReturnPeriod": "graas_mkp_product_performance",
    "shopee_onsiteCampaignAfterReturnPeriod": "graas_mkp_onsite_campaigns",
    "shopee_productOverviewMonthlyBackFill": "graas_mkp_product_overview_daily",
    "shopee_marketingVoucherMonthlyBackFill": "graas_mkp_deals_trends_daily",
    "shopee_marketingShippingFeePromotionMonthlyBackFill": "graas_mkp_deals_trends_daily",
    "shopee_storeKeyMetricsMonthlyBackFill": "graas_mkp_shop_stats_daily",
    "shopee_marketingAddOnDealMonthlyBackFill": "graas_mkp_deals_trends_daily",
    "shopee_marketingBundleDealMonthlyBackFill": "graas_mkp_deals_trends_daily",
    "shopee_marketingFlashDealMonthlyBackFill": "graas_mkp_deals_trends_daily",
    "shopee_trafficOverviewMonthlyBackFill": "graas_mkp_traffic_overview_daily",
    "lazada_offsite": "graas_mkp_offsite_campaigns",
    "lazada_onsiteKeyword": "graas_mkp_onsite_keywords",
    "lazada_customerInsight": "graas_mkp_shop_stats_daily",
    "lazada_customerInsightMonthly": "graas_mkp_shop_stats_daily",
    "lazada_storeKeyMetrics": "graas_mkp_shop_stats_daily",
    "lazada_storeKeyMetricsMonthly": "graas_mkp_shop_stats_daily",
    "lazada_sponsoredDiscoveryReport": "graas_mkp_onsite_campaigns",
    "lazada_sponsoredDiscoveryReportMonthly": "graas_mkp_onsite_campaigns",
    "lazada_sponsoredAffiliateReport": "graas_mkp_affiliate_report_daily",
    "lazada_sponsoredAffiliateReportMonthly": "graas_mkp_affiliate_report_daily",
    "lazada_productPerformance": "graas_mkp_product_performance",
    "lazada_productPerformanceAfterReturnPeriod": "graas_mkp_product_performance",
    "lazada_storeKeyMetricsMonthlyBackFill": "graas_mkp_shop_stats_daily",
    "lazada_sponsoredDiscoveryReportMonthlyBackFill": "graas_mkp_onsite_campaigns",
    "lazada_sponsoredAffiliateReportMonthlyBackFill": "graas_mkp_affiliate_report_daily",
    "lazada_customerInsightMonthlyBackFill": "graas_mkp_shop_stats_daily",
    "amazon_onsiteSponsoredDisplayCampaign": "graas_amazon_campaigns",
    "amazon_onsiteSponsoredProductsCampaign":"graas_amazon_campaigns",
    "amazon_onsiteSponsoredBrandsCampaign":"graas_amazon_campaigns",
    "amazon_trafficKeyMetrics":"graas_mkp_traffic_overview_daily",
    "amazon_storeKeyMetrics":"graas_mkp_product_overview_daily",
    "amazon_returnOrderReport":"graas_mkp_returned_orders_daily",
    "amazon_productPerformance":"graas_mkp_product_performance",
    "amazon_sponsoredDisplayAdvertisedProduct":"graas_mkp_product_campaign_performance",
    "amazon_sponsoredProductsAdvertisedProduct":"graas_mkp_product_campaign_performance",
    "amazon_sponsoredBrandsAttributedPurchases":"graas_mkp_product_campaign_performance",
    "amazon_storeKeyMetricsMonthly":"graas_mkp_shop_stats_daily",
    "amazon_trafficKeyMetricsMonthly":"graas_mkp_shop_stats_daily",
    "amazon_storeKeyMetricsMonthlyBackFill":"graas_mkp_shop_stats_daily",
    "amazon_trafficKeyMetricsMonthlyBackFill":"graas_mkp_shop_stats_daily",
    "flipkart_BrandAdsCampaign":"graas_flipkart_campaigns",
    "flipkart_PCACampaign":"graas_flipkart_campaigns",
    "flipkart_PLACampaign":"graas_flipkart_campaigns",
    "flipkart_PLACampaignSellerPortal":"graas_flipkart_campaigns",
    "flipkart_DisplayAdsCampaign":"graas_flipkart_campaigns",
    "flipkart_PLAConsolidatedFSN":"graas_mkp_product_campaign_performance",
    "flipkart_PLAConsolidatedFSNSellerPortal":"graas_mkp_product_campaign_performance",
    "flipkart_PCAProductPagePerformance":"graas_mkp_product_campaign_performance",
    "flipkart_searchTrafficReport":"graas_mkp_traffic_overview_daily",
    "tokopedia_storeKeyMetrics":"graas_mkp_traffic_overview_daily",
    "tokopedia_storeKeyMetricsMonthly":"graas_mkp_shop_stats_daily",
    "tokopedia_trafficOverview":"graas_mkp_traffic_overview_daily",
    "tokopedia_productReport":"graas_mkp_product_overview_daily",
    "tokopedia_customerInsight":"graas_mkp_traffic_overview_daily",
    "tokopedia_customerInsightMonthly":"graas_mkp_shop_stats_daily",
    "tokopedia_customerInsightMonthlyBackFill":"graas_mkp_shop_stats_daily",
    "tokopedia_storeKeyMetricsMonthlyBackFill":"graas_mkp_shop_stats_daily"
}

==> graas-observability-utility-1.5.1.tar.gz: graas-observability-utility-1.5.1/graas_utilities/configs.py <==
mappingObject = {
    "shopee_trafficOverview": "graas_mkp_traffic_overview_hourly",
    "shopee_trafficOverviewMonthly": "graas_mkp_traffic_overview_daily",
    "shopee_storeKeyMetrics": "graas_mkp_shop_stats_daily",
    "shopee_storeKeyMetricsMonthly": "graas_mkp_shop_stats_daily",
    "shopee_productOverview": "Shopee_Product_Overview_Hourly_Daily_Report",
    "shopee_productOverviewMonthly": "Shopee_Product_Overview_Daily_Monthly_Report",
    "shopee_onsiteCampaign": "Shopee_mkp_onsite_campaign_daily_Report",
    "shopee_onsiteKeyword": "graas_mkp_onsite_keywords",
    "shopee_productPerformance": "Shopee_Product_Performance_Daily_Report",
    "shopee_marketingAddOnDeal": "graas_mkp_deals_overview_daily",
    "shopee_marketingAddOnDealMonthly": "graas_mkp_deals_trends_daily",
    "shopee_marketingShippingFeePromotion": "graas_mkp_voucher_performance_daily",
    "shopee_marketingShippingFeePromotionMonthly": "graas_mkp_deals_trends_daily",
    "shopee_marketingVoucher": "graas_mkp_voucher_performance_daily",
    "shopee_marketingVoucherMonthly": "graas_mkp_deals_trends_daily",
    "shopee_marketingBundleDeal": "graas_mkp_deals_overview_daily",
    "shopee_marketingBundleDealMonthly": "graas_mkp_deals_trends_daily",
    "shopee_marketingFlashDeal": "graas_mkp_deals_overview_daily",
    "shopee_marketingFlashDealMonthly": "graas_mkp_deals_trends_daily",
    "shopee_productPerformanceAfterReturnPeriod": "Shopee_Product_Performance_Daily_Report",
    "shopee_onsiteCampaignAfterReturnPeriod": "Shopee_mkp_onsite_campaign_daily_Report",
    "shopee_productOverviewMonthlyBackFill": "Shopee_Product_Overview_Daily_Monthly_Report",
    "shopee_marketingVoucherMonthlyBackFill": "graas_mkp_deals_trends_daily",
    "shopee_marketingShippingFeePromotionMonthlyBackFill": "graas_mkp_deals_trends_daily",
    "shopee_storeKeyMetricsMonthlyBackFill": "graas_mkp_shop_stats_daily",
    "shopee_marketingAddOnDealMonthlyBackFill": "graas_mkp_deals_trends_daily",
    "shopee_marketingBundleDealMonthlyBackFill": "graas_mkp_deals_trends_daily",
    "shopee_marketingFlashDealMonthlyBackFill": "graas_mkp_deals_trends_daily",
    "shopee_trafficOverviewMonthlyBackFill": "graas_mkp_traffic_overview_daily",
    "lazada_offsite": "graas_mkp_offsite_campaigns",
    "lazada_onsiteKeyword": "graas_mkp_onsite_keywords",
    "lazada_customerInsight": "graas_mkp_shop_stats_daily",
    "lazada_customerInsightMonthly": "graas_mkp_shop_stats_daily",
    "lazada_storeKeyMetrics": "graas_mkp_shop_stats_daily",
    "lazada_storeKeyMetricsMonthly": "graas_mkp_shop_stats_daily",
    "lazada_sponsoredDiscoveryReport": "Lazada_mkp_onsite_campaign_monthly_Report",
    "lazada_sponsoredDiscoveryReportMonthly": "Lazada_mkp_onsite_campaign_monthly_Report",
    "lazada_sponsoredAffiliateReport": "graas_mkp_affiliate_report_daily",
    "lazada_sponsoredAffiliateReportMonthly": "graas_mkp_affiliate_report_daily",
    "lazada_productPerformance": "Lazada_Product_Performance_Daily_Report",
    "lazada_productPerformanceAfterReturnPeriod": "Lazada_Product_Performance_Daily_Report",
    "lazada_storeKeyMetricsMonthlyBackFill": "graas_mkp_shop_stats_daily",
    "lazada_sponsoredDiscoveryReportMonthlyBackFill": "Lazada_mkp_onsite_campaign_monthly_Report",
    "lazada_sponsoredAffiliateReportMonthlyBackFill": "graas_mkp_affiliate_report_daily",
    "lazada_customerInsightMonthlyBackFill": "graas_mkp_shop_stats_daily",
    "amazon_onsiteSponsoredDisplayCampaign": "graas_amazon_campaigns",
    "amazon_onsiteSponsoredProductsCampaign":"graas_amazon_campaigns",
    "amazon_onsiteSponsoredBrandsCampaign":"graas_amazon_campaigns",
    "amazon_trafficKeyMetrics":"graas_mkp_traffic_overview_daily",
    "amazon_storeKeyMetrics":"Amazon_Store_Key_Metrics_Daily_Report",
    "amazon_returnOrderReport":"graas_mkp_returned_orders_daily",
    "amazon_productPerformance":"Amazon_Product_Performance_Daily_Report",
    "amazon_sponsoredDisplayAdvertisedProduct":"graas_mkp_product_campaign_performance",
    "amazon_sponsoredProductsAdvertisedProduct":"graas_mkp_product_campaign_performance",
    "amazon_sponsoredBrandsAttributedPurchases":"graas_mkp_product_campaign_performance",
    "amazon_storeKeyMetricsMonthly":"graas_mkp_shop_stats_daily",
    "amazon_trafficKeyMetricsMonthly":"graas_mkp_shop_stats_daily",
    "amazon_storeKeyMetricsMonthlyBackFill":"graas_mkp_shop_stats_daily",
    "amazon_trafficKeyMetricsMonthlyBackFill":"graas_mkp_shop_stats_daily",
    "flipkart_BrandAdsCampaign":"graas_flipkart_campaigns",
    "flipkart_PCACampaign":"graas_flipkart_campaigns",
    "flipkart_PLACampaign":"graas_flipkart_campaigns",
    "flipkart_PLACampaignSellerPortal":"graas_flipkart_campaigns",
    "flipkart_DisplayAdsCampaign":"graas_flipkart_campaigns",
    "flipkart_PLAConsolidatedFSN":"graas_mkp_product_campaign_performance",
    "flipkart_PLAConsolidatedFSNSellerPortal":"graas_mkp_product_campaign_performance",
    "flipkart_PCAProductPagePerformance":"graas_mkp_product_campaign_performance",
    "flipkart_searchTrafficReport":"graas_mkp_traffic_overview_daily",
    "tokopedia_storeKeyMetrics":"graas_mkp_traffic_overview_daily",
    "tokopedia_storeKeyMetricsMonthly":"graas_mkp_shop_stats_daily",
    "tokopedia_trafficOverview":"graas_mkp_traffic_overview_daily",
    "tokopedia_productReport":"Tokopedia_Product_Overview_Daily_Report",
    "tokopedia_customerInsight":"graas_mkp_traffic_overview_daily",
    "tokopedia_customerInsightMonthly":"graas_mkp_shop_stats_daily",
    "tokopedia_customerInsightMonthlyBackFill":"graas_mkp_shop_stats_daily",
    "tokopedia_storeKeyMetricsMonthlyBackFill":"graas_mkp_shop_stats_daily"
}
